# jaxlem

jaxlem is a Python implementation of LEM slope stability built upon JAX.

## Content

So far, the project includes the following features:
* Slope stability analysis with undrained shear strength.
* Calculation of the FoS using vmap over potential failure circles.
* Calculation of the FoS using Gradient Descent.
* Reliability analysis with Random Fields using Monte Carlo via vmap.
* Reliability analysis with Random Fields using FORM.

